/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/slave/mozilla-central-linux64-xulrunner/build/dom/indexedDB/nsIIDBObjectStore.idl
 */

#ifndef __gen_nsIIDBObjectStore_h__
#define __gen_nsIIDBObjectStore_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDOMDOMStringList; /* forward declaration */


/* starting interface:    nsIIDBObjectStore */
#define NS_IIDBOBJECTSTORE_IID_STR "783a49b0-c5f0-4d97-9349-532f4ec1f7ce"

#define NS_IIDBOBJECTSTORE_IID \
  {0x783a49b0, 0xc5f0, 0x4d97, \
    { 0x93, 0x49, 0x53, 0x2f, 0x4e, 0xc1, 0xf7, 0xce }}

/**
 * IDBObjectStore interface.  See
 * http://dev.w3.org/2006/webapi/WebSimpleDB/#idl-def-IDBObjectStore for more
 * information.
 */
class NS_NO_VTABLE NS_SCRIPTABLE nsIIDBObjectStore : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIDBOBJECTSTORE_IID)

  /* readonly attribute DOMString name; */
  NS_SCRIPTABLE NS_IMETHOD GetName(nsAString & aName) = 0;

  /* readonly attribute DOMString keyPath; */
  NS_SCRIPTABLE NS_IMETHOD GetKeyPath(nsAString & aKeyPath) = 0;

  /* readonly attribute nsIDOMDOMStringList indexNames; */
  NS_SCRIPTABLE NS_IMETHOD GetIndexNames(nsIDOMDOMStringList * *aIndexNames) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIIDBObjectStore, NS_IIDBOBJECTSTORE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIDBOBJECTSTORE \
  NS_SCRIPTABLE NS_IMETHOD GetName(nsAString & aName); \
  NS_SCRIPTABLE NS_IMETHOD GetKeyPath(nsAString & aKeyPath); \
  NS_SCRIPTABLE NS_IMETHOD GetIndexNames(nsIDOMDOMStringList * *aIndexNames); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIDBOBJECTSTORE(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetName(nsAString & aName) { return _to GetName(aName); } \
  NS_SCRIPTABLE NS_IMETHOD GetKeyPath(nsAString & aKeyPath) { return _to GetKeyPath(aKeyPath); } \
  NS_SCRIPTABLE NS_IMETHOD GetIndexNames(nsIDOMDOMStringList * *aIndexNames) { return _to GetIndexNames(aIndexNames); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIDBOBJECTSTORE(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetName(nsAString & aName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetName(aName); } \
  NS_SCRIPTABLE NS_IMETHOD GetKeyPath(nsAString & aKeyPath) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetKeyPath(aKeyPath); } \
  NS_SCRIPTABLE NS_IMETHOD GetIndexNames(nsIDOMDOMStringList * *aIndexNames) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIndexNames(aIndexNames); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsIDBObjectStore : public nsIIDBObjectStore
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIDBOBJECTSTORE

  nsIDBObjectStore();

private:
  ~nsIDBObjectStore();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsIDBObjectStore, nsIIDBObjectStore)

nsIDBObjectStore::nsIDBObjectStore()
{
  /* member initializers and constructor code */
}

nsIDBObjectStore::~nsIDBObjectStore()
{
  /* destructor code */
}

/* readonly attribute DOMString name; */
NS_IMETHODIMP nsIDBObjectStore::GetName(nsAString & aName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute DOMString keyPath; */
NS_IMETHODIMP nsIDBObjectStore::GetKeyPath(nsAString & aKeyPath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIDOMDOMStringList indexNames; */
NS_IMETHODIMP nsIDBObjectStore::GetIndexNames(nsIDOMDOMStringList * *aIndexNames)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIIDBObjectStore_h__ */
