/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/slave/mozilla-central-linux64-xulrunner/build/dom/indexedDB/nsIIDBObjectStoreRequest.idl
 */

#ifndef __gen_nsIIDBObjectStoreRequest_h__
#define __gen_nsIIDBObjectStoreRequest_h__


#ifndef __gen_nsIIDBObjectStore_h__
#include "nsIIDBObjectStore.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIIDBIndexRequest; /* forward declaration */

class nsIIDBKeyRange; /* forward declaration */

class nsIIDBRequest; /* forward declaration */

class nsIVariant; /* forward declaration */


/* starting interface:    nsIIDBObjectStoreRequest */
#define NS_IIDBOBJECTSTOREREQUEST_IID_STR "ce65fbc2-06a0-4f1c-89e4-0d9a636179c7"

#define NS_IIDBOBJECTSTOREREQUEST_IID \
  {0xce65fbc2, 0x06a0, 0x4f1c, \
    { 0x89, 0xe4, 0x0d, 0x9a, 0x63, 0x61, 0x79, 0xc7 }}

/**
 * nsIIDBObjectStoreRequest interface.  See
 * http://dev.w3.org/2006/webapi/WebSimpleDB/#idl-def-nsIIDBObjectStoreRequest
 * for more information.
 */
class NS_NO_VTABLE NS_SCRIPTABLE nsIIDBObjectStoreRequest : public nsIIDBObjectStore {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIDBOBJECTSTOREREQUEST_IID)

  /* nsIIDBRequest get (in nsIVariant key); */
  NS_SCRIPTABLE NS_IMETHOD Get(nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM) = 0;

  /* [optional_argc] nsIIDBRequest getAll ([optional] in nsIIDBKeyRange key, [optional] in unsigned long limit); */
  NS_SCRIPTABLE NS_IMETHOD GetAll(nsIIDBKeyRange *key, PRUint32 limit, PRUint8 _argc, nsIIDBRequest **_retval NS_OUTPARAM) = 0;

  /* nsIIDBRequest add (in nsIVariant value, [optional] in nsIVariant key); */
  NS_SCRIPTABLE NS_IMETHOD Add(nsIVariant *value, nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM) = 0;

  /* nsIIDBRequest modify (in nsIVariant value, [optional] in nsIVariant key); */
  NS_SCRIPTABLE NS_IMETHOD Modify(nsIVariant *value, nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM) = 0;

  /* nsIIDBRequest addOrModify (in nsIVariant value, [optional] in nsIVariant key); */
  NS_SCRIPTABLE NS_IMETHOD AddOrModify(nsIVariant *value, nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM) = 0;

  /* nsIIDBRequest remove (in nsIVariant key); */
  NS_SCRIPTABLE NS_IMETHOD Remove(nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM) = 0;

  /* [optional_argc] nsIIDBRequest openCursor ([optional] in nsIIDBKeyRange range, [optional] in unsigned short direction, [optional] in boolean preload); */
  NS_SCRIPTABLE NS_IMETHOD OpenCursor(nsIIDBKeyRange *range, PRUint16 direction, PRBool preload, PRUint8 _argc, nsIIDBRequest **_retval NS_OUTPARAM) = 0;

  /* nsIIDBRequest createIndex (in AString name, in AString keyPath, [optional] in boolean unique); */
  NS_SCRIPTABLE NS_IMETHOD CreateIndex(const nsAString & name, const nsAString & keyPath, PRBool unique, nsIIDBRequest **_retval NS_OUTPARAM) = 0;

  /* nsIIDBIndexRequest index (in AString name); */
  NS_SCRIPTABLE NS_IMETHOD Index(const nsAString & name, nsIIDBIndexRequest **_retval NS_OUTPARAM) = 0;

  /* nsIIDBRequest removeIndex (in AString name); */
  NS_SCRIPTABLE NS_IMETHOD RemoveIndex(const nsAString & name, nsIIDBRequest **_retval NS_OUTPARAM) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIIDBObjectStoreRequest, NS_IIDBOBJECTSTOREREQUEST_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIDBOBJECTSTOREREQUEST \
  NS_SCRIPTABLE NS_IMETHOD Get(nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD GetAll(nsIIDBKeyRange *key, PRUint32 limit, PRUint8 _argc, nsIIDBRequest **_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD Add(nsIVariant *value, nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD Modify(nsIVariant *value, nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD AddOrModify(nsIVariant *value, nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD Remove(nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD OpenCursor(nsIIDBKeyRange *range, PRUint16 direction, PRBool preload, PRUint8 _argc, nsIIDBRequest **_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD CreateIndex(const nsAString & name, const nsAString & keyPath, PRBool unique, nsIIDBRequest **_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD Index(const nsAString & name, nsIIDBIndexRequest **_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD RemoveIndex(const nsAString & name, nsIIDBRequest **_retval NS_OUTPARAM); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIDBOBJECTSTOREREQUEST(_to) \
  NS_SCRIPTABLE NS_IMETHOD Get(nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM) { return _to Get(key, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetAll(nsIIDBKeyRange *key, PRUint32 limit, PRUint8 _argc, nsIIDBRequest **_retval NS_OUTPARAM) { return _to GetAll(key, limit, _argc, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD Add(nsIVariant *value, nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM) { return _to Add(value, key, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD Modify(nsIVariant *value, nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM) { return _to Modify(value, key, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD AddOrModify(nsIVariant *value, nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM) { return _to AddOrModify(value, key, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD Remove(nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM) { return _to Remove(key, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD OpenCursor(nsIIDBKeyRange *range, PRUint16 direction, PRBool preload, PRUint8 _argc, nsIIDBRequest **_retval NS_OUTPARAM) { return _to OpenCursor(range, direction, preload, _argc, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD CreateIndex(const nsAString & name, const nsAString & keyPath, PRBool unique, nsIIDBRequest **_retval NS_OUTPARAM) { return _to CreateIndex(name, keyPath, unique, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD Index(const nsAString & name, nsIIDBIndexRequest **_retval NS_OUTPARAM) { return _to Index(name, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD RemoveIndex(const nsAString & name, nsIIDBRequest **_retval NS_OUTPARAM) { return _to RemoveIndex(name, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIDBOBJECTSTOREREQUEST(_to) \
  NS_SCRIPTABLE NS_IMETHOD Get(nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->Get(key, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetAll(nsIIDBKeyRange *key, PRUint32 limit, PRUint8 _argc, nsIIDBRequest **_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAll(key, limit, _argc, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD Add(nsIVariant *value, nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->Add(value, key, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD Modify(nsIVariant *value, nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->Modify(value, key, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD AddOrModify(nsIVariant *value, nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddOrModify(value, key, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD Remove(nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->Remove(key, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD OpenCursor(nsIIDBKeyRange *range, PRUint16 direction, PRBool preload, PRUint8 _argc, nsIIDBRequest **_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->OpenCursor(range, direction, preload, _argc, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD CreateIndex(const nsAString & name, const nsAString & keyPath, PRBool unique, nsIIDBRequest **_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateIndex(name, keyPath, unique, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD Index(const nsAString & name, nsIIDBIndexRequest **_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->Index(name, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD RemoveIndex(const nsAString & name, nsIIDBRequest **_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveIndex(name, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsIDBObjectStoreRequest : public nsIIDBObjectStoreRequest
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIDBOBJECTSTOREREQUEST

  nsIDBObjectStoreRequest();

private:
  ~nsIDBObjectStoreRequest();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsIDBObjectStoreRequest, nsIIDBObjectStoreRequest)

nsIDBObjectStoreRequest::nsIDBObjectStoreRequest()
{
  /* member initializers and constructor code */
}

nsIDBObjectStoreRequest::~nsIDBObjectStoreRequest()
{
  /* destructor code */
}

/* nsIIDBRequest get (in nsIVariant key); */
NS_IMETHODIMP nsIDBObjectStoreRequest::Get(nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [optional_argc] nsIIDBRequest getAll ([optional] in nsIIDBKeyRange key, [optional] in unsigned long limit); */
NS_IMETHODIMP nsIDBObjectStoreRequest::GetAll(nsIIDBKeyRange *key, PRUint32 limit, PRUint8 _argc, nsIIDBRequest **_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIIDBRequest add (in nsIVariant value, [optional] in nsIVariant key); */
NS_IMETHODIMP nsIDBObjectStoreRequest::Add(nsIVariant *value, nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIIDBRequest modify (in nsIVariant value, [optional] in nsIVariant key); */
NS_IMETHODIMP nsIDBObjectStoreRequest::Modify(nsIVariant *value, nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIIDBRequest addOrModify (in nsIVariant value, [optional] in nsIVariant key); */
NS_IMETHODIMP nsIDBObjectStoreRequest::AddOrModify(nsIVariant *value, nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIIDBRequest remove (in nsIVariant key); */
NS_IMETHODIMP nsIDBObjectStoreRequest::Remove(nsIVariant *key, nsIIDBRequest **_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [optional_argc] nsIIDBRequest openCursor ([optional] in nsIIDBKeyRange range, [optional] in unsigned short direction, [optional] in boolean preload); */
NS_IMETHODIMP nsIDBObjectStoreRequest::OpenCursor(nsIIDBKeyRange *range, PRUint16 direction, PRBool preload, PRUint8 _argc, nsIIDBRequest **_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIIDBRequest createIndex (in AString name, in AString keyPath, [optional] in boolean unique); */
NS_IMETHODIMP nsIDBObjectStoreRequest::CreateIndex(const nsAString & name, const nsAString & keyPath, PRBool unique, nsIIDBRequest **_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIIDBIndexRequest index (in AString name); */
NS_IMETHODIMP nsIDBObjectStoreRequest::Index(const nsAString & name, nsIIDBIndexRequest **_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIIDBRequest removeIndex (in AString name); */
NS_IMETHODIMP nsIDBObjectStoreRequest::RemoveIndex(const nsAString & name, nsIIDBRequest **_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIIDBObjectStoreRequest_h__ */
